@@ -1,7 +1,7 @@
 import numpy as np
 import libpysal
 import geopandas as gpd
-from .. import AZP
+from spopt.region import AZP
 
 def test_azp():
     pth = libpysal.examples.get_path("mexicojoin.shp")
@@ -14,4 +14,4 @@ def test_azp():
     model.solve()
     labels = np.array(
         [0, 0, 2, 1, 1, 2, 2, 2, 3, 3, 3, 1, 2, 4, 4, 2, 4, 3, 3, 3, 4, 3, 0, 0, 2, 2, 2, 1, 2, 1, 1, 4])
-    return np.array_equal(model.labels_, labels)
\ No newline at end of file
+    return np.array_equal(model.labels_, labels)
