@@ -5,7 +5,7 @@ import os
 import sys
 
 # sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), ".")))
-from .. import MaxPHeuristic
+from spopt.region import MaxPHeuristic
 
 
 def test_MaxPHeuristic():
