@@ -4,7 +4,7 @@ import os
 import sys
 
 # sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), ".")))
-from .. import RegionKMeansHeuristic
+from spopt.region import RegionKMeansHeuristic
 
 
 def test_RegionKMeansHeuristic():
