@@ -1,7 +1,7 @@
 import numpy as np
 import libpysal
 import geopandas as gpd
-from .. import Skater
+from spopt.region import Skater
 import unittest
 
 class TestSkater(unittest.TestCase):
@@ -54,4 +54,4 @@ class TestSkater(unittest.TestCase):
                 1,
             ]
         )
-        np.testing.assert_equal(observed_labels, known_labels)
\ No newline at end of file
+        np.testing.assert_equal(observed_labels, known_labels)
